Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon AppFlow.

Actions, resources, and condition keys for Amazon AppFlow - Service Authorization Reference

# Actions, resources, and condition keys for Amazon AppFlow

Amazon AppFlow (service prefix: `appflow` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon AppFlow
- Resource types defined by Amazon AppFlow
- Condition keys for Amazon AppFlow

## Actions defined by Amazon AppFlow

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CancelFlowExecutions | Grants permission to cancel in-progress executions of an Amazon AppFlow flow | Write | flow* |  |
CreateConnectorProfile | Grants permission to create a login profile to be used with Amazon AppFlow flows | Write |  |  |
CreateFlow | Grants permission to create an Amazon AppFlow flow | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeleteConnectorProfile | Grants permission to delete a login profile configured in Amazon AppFlow | Write | connectorprofile* |  |
DeleteFlow | Grants permission to delete an Amazon AppFlow flow | Write | flow* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DescribeConnector | Grants permission to describe a connector registered in Amazon AppFlow | Read | connector* |  |
DescribeConnectorEntity | Grants permission to describe all fields for an object in a login profile configured in Amazon AppFlow | Read | connectorprofile* |  |
DescribeConnectorFields [permission only] | Grants permission to describe all fields for an object in a login profile configured in Amazon AppFlow (Console Only) | Read | connectorprofile* |  |
DescribeConnectorProfiles | Grants permission to describe all login profiles configured in Amazon AppFlow | Read |  |  |
DescribeConnectors | Grants permission to describe all connectors supported by Amazon AppFlow | Read |  |  |
DescribeFlow | Grants permission to describe a specific flow configured in Amazon AppFlow | Read | flow* |  |
DescribeFlowExecution [permission only] | Grants permission to describe all flow executions for a flow configured in Amazon AppFlow (Console Only) | Read | flow* |  |
DescribeFlowExecutionRecords | Grants permission to describe all flow executions for a flow configured in Amazon AppFlow | Read | flow* |  |
DescribeFlows [permission only] | Grants permission to describe all flows configured in Amazon AppFlow (Console Only) | Read |  |  |
ListConnectorEntities | Grants permission to list all objects for a login profile configured in Amazon AppFlow | List | connectorprofile* |  |
ListConnectorFields [permission only] | Grants permission to list all objects for a login profile configured in Amazon AppFlow (Console Only) | Read | connectorprofile* |  |
ListConnectors | Grants permission to list all connectors supported in Amazon AppFlow | List | connector* |  |
ListFlows | Grants permission to list all flows configured in Amazon AppFlow | List | flow* |  |
ListTagsForResource | Grants permission to list tags for a flow | Read | flow* |  |
RegisterConnector | Grants permission to register an Amazon AppFlow connector | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
ResetConnectorMetadataCache | Grants permission to resets metadata of connector entities that Amazon AppFlow stored in its cache | Write | connectorprofile* |  |
RunFlow [permission only] | Grants permission to run a flow configured in Amazon AppFlow (Console Only) | Write | flow* |  |
StartFlow | Grants permission to activate (for scheduled and event-triggered flows) or run (for on-demand flows) a flow configured in Amazon AppFlow | Write | flow* |  |
StopFlow | Grants permission to deactivate a scheduled or event-triggered flow configured in Amazon AppFlow | Write | flow* |  |
TagResource | Grants permission to tag a flow or a connector | Tagging | connector |  |
flow |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UnRegisterConnector | Grants permission to un-register a connector in Amazon AppFlow | Write | connector* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to untag a flow or a connector | Tagging | connector |  |
flow |  |
| aws:TagKeys |
UpdateConnectorProfile | Grants permission to update a login profile configured in Amazon AppFlow | Write | connectorprofile* |  |
UpdateConnectorRegistration | Grants permission to update a registered connector configured in Amazon AppFlow | Write | connector* |  |
UpdateFlow | Grants permission to update a flow configured in Amazon AppFlow | Write | flow* |  |
UseConnectorProfile [permission only] | Grants permission to use a connector profile while creating a flow in Amazon AppFlow | Write | connectorprofile* |  |

## Resource types defined by Amazon AppFlow

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
connectorprofile | `arn:$ { Partition}:appflow:$ { Region}:$ { Account}:connectorprofile/$ { ProfileName}` |
flow | `arn:$ { Partition}:appflow:$ { Region}:$ { Account}:flow/$ { FlowName}` | aws:ResourceTag/${TagKey}
connector | `arn:$ { Partition}:appflow:$ { Region}:$ { Account}:connector/$ { ConnectorLabel}` | aws:ResourceTag/${TagKey}

## Condition keys for Amazon AppFlow

Amazon AppFlow defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by allowed set of values for each of the tags | String
aws:ResourceTag/${TagKey} | Filters access by tag-value associated with the resource | String
aws:TagKeys | Filters access by presence of mandatory tags in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.